@@ -63,8 +63,11 @@
             x <- x[,-bad] 
             nvar <- nvar - n.bad
              }
-        if(discrete) {response.freq <- response.frequencies(x,max=max) } else {response.freq=NULL} #added 12/4/23
-         C <- cov(x,use=use)} else {C <- x}  #to find average R, we need to find R, not C  cov2cor(C) != R  !
+        if(discrete) {response.freq <- responseFrequency(x,max=max) } else {response.freq=NULL} #added 12/4/23
+        
+         C <- cov(x,use=use)
+         R <- cor(x,use=use)} else {C <- x
+                                    R <- cov2cor(C)}  #to find average R, we need to find R, not C  cov2cor(C) != R  !  added 1/15/24
         
         if(is.null(colnames(x)))  colnames(x) <- paste0("V",1:nvar)
          #flip items if needed and wanted
@@ -99,7 +102,8 @@
          			           
          			           
         			 key.d <- diag(keys)
-                     C <- key.d %*% C %*% key.d
+        			 R <- key.d %*% R %*% key.d   #added 5/17/24 following report of a bug
+        		     C <- key.d %*% C %*% key.d
                      signkey <- strtrim(keys,1)
             		 signkey[signkey=="1"] <- ""
                      colnames(x) <- paste(colnames(x),signkey,sep="")
@@ -128,7 +132,7 @@
                  totals <- TRUE
                  }
           
-         R <- cov2cor(C)
+       #  R <- cov2cor(C)   #need to actually find correlations to treat missing values correctly  
          drop.item <- vector("list",nvar)
          alpha.total <- alpha.1(C,R)
          if(nvar > 2) {
