@@ -473,7 +473,7 @@ if(any( !(c(y,x,z,ex) %in% colnames(data)) )) {
         
        
      	if(is.null(n.obs)) {set.cor <- list(coefficients=beta,R=sqrt(R2),R2=R2,Rset=Rset,T=T,cancor = cc, cancor2=cc2,
-     	         raw=raw,residual=resid,SE.resid=Residual.se,df=c(k,df),ruw=ruw,Ruw=Ruw, x.matrix=C[x,x],y.matrix=C[y,y],r0=xy.matrix,
+     	         raw=raw,residual=resid,SE.resid=Residual.se,df=c(k,df),ruw=ruw,Ruw=Ruw, x.matrix=C[x,x],y.matrix=C[y,y],r0 =C[x,y,drop=FALSE],
      	          VIF=VIF,z=z,std=std,Vaxy=Vaxy,Xmat=Lmat, Ymat=Mmat, Call = cl)
      	           } else {
      	    set.cor <- list(coefficients=beta,se=se,t=tvalue,Probability = prob,ci=confid.beta,
