@@ -254,10 +254,11 @@ return(y)}
  #modified July 4, 2017 to allow for omega output as well
  #modified June 23, 2018 to limit to top n items per factor and abs(loading) > cut
  #modified April 30, 2020 to include the ability to handle bassAckward output
+ #221/26 added CFA output  and added the maxlength parameter
 "fa.lookup"  <-
-   function(f,dictionary=NULL,digits=2,cut=.0,n=NULL,sort=TRUE) {
+   function(f,dictionary=NULL,digits=2,cut=.0,n=NULL,sort=TRUE, maxlength=NULL) {
     omega <- bassAck <- none <- lavaan <- NA    #weird requirement to avoid being global
-   if(length(class(f)) > 1){ obnames <- cs(omega, fa, principal, iclust,bassAck, none)
+   if(length(class(f)) > 1){ obnames <- cs(omega, fa, principal, iclust,bassAck, CFA,none)
      value <- inherits(f, obnames, which=TRUE)
 			   if (any(value > 1)) {value <- obnames[which(value >0)]} else {value <- "none"}}
    if(sort & (value !="bassAck")) {f <- fa.sort(f)}
@@ -283,6 +284,9 @@ return(y)}
                f <- fa.sort(f)
                colnames(f) <- paste0("F",1:ncol(f))           
     },
+    CFA = {h2 <- f$communality
+              f <- f$loading 
+              com <- NULL       },
     none = {f <- f
             h2 <- NULL})
     
@@ -294,8 +298,14 @@ return(y)}
    rownames(f) <- ord
    if(!is.null(dictionary))  { 
    contents <- lookup(rownames(f),dictionary)} else {message("fa.lookup requires a dictionary, otherwise just use fa.sort")}
-   contents <- format(contents, justify="left")
-   if(!is.null(h2)) {results <- data.frame(round(unclass(f),digits=digits),h2=round(h2,digits=digits),com=round(com,digits=digits))} else {
+
+  if(!is.null(maxlength) )  contents <- apply(contents,1,substr, 1, maxlength)
+  contents <- format(contents, justify="left")
+   if(!is.null(h2)) {
+   		if(!is.null(com)){ results <- data.frame(round(unclass(f),digits=digits),h2=round(h2,digits=digits),com=round(com,digits=digits))
+   	      } else {
+   	results <- data.frame(round(unclass(f),digits=digits),h2=round(h2,digits=digits))
+         } } else {
    results <- data.frame(round(unclass(f),digits=digits))}
    
    results <- merge(results,contents,by="row.names",all.x=TRUE,sort=FALSE)
@@ -694,6 +704,7 @@ pretty}
 "char2numeric" <- function(x,flag=TRUE) {
 #convert non numeric (factors, characters, logical) to numeric
  nvar <- NCOL(x)
+ if((nvar ==1 ) && (!is.data.frame(x))) {x <- as.character(x) } else {
  for(i in 1:nvar) {   
         if(!is.numeric(x[[i]] ))  {
                                   if(is.factor(unlist(x[[i]])) | is.character(unlist(x[[i]]))) {  x[[i]] <- as.numeric(as.factor(x[[i]])) 
@@ -702,6 +713,7 @@ pretty}
                          if(flag) colnames(x)[i] <- paste0(colnames(x)[i],"*")
                           }                     
               } 
+              }
               invisible(x)} 
               
 # added the is.logical test  23/06/24
