@@ -387,7 +387,7 @@ theta.max <- max(theta,na.rm=TRUE)
 binrange <- cut(theta, breaks = breaks)
 binnums <- as.numeric(binrange)
 items <- as.matrix(items)
-stats <- by(items,binnums,function(x) response.frequencies(x,uniqueitems=uniqueitems))
+stats <- by(items,binnums,function(x) responseFrequencies(x,uniqueitems=uniqueitems))
 stats.m <- unlist(stats)
 stats.m <- matrix(stats.m,ncol=nvar*nalt,byrow=TRUE)
 theta <- seq(theta.min,theta.max,length.out=breaks)
